---
title: <span class="badge object-type-scalar"></span> GigaFlopsPerSecond
---
# <span class="badge object-type-scalar"></span> GigaFlopsPerSecond

Computation: GFLOP/s

## Definition

```python
# Computation: GFLOP/s
GigaFlopsPerSecond: typing.Literal["gflops"] = "gflops"
```
